@@ -13,7 +13,7 @@ import attr
 
 import pycodestyle
 
-__version__ = "21.9.1"
+__version__ = "21.9.2"
 
 LOG = logging.getLogger("flake8.bugbear")
 
@@ -125,6 +125,8 @@ def _to_name_str(node):
     # "pkg.mod.error", handling any depth of attribute accesses.
     if isinstance(node, ast.Name):
         return node.id
+    if isinstance(node, ast.Call):
+        return _to_name_str(node.func)
     try:
         return _to_name_str(node.value) + "." + node.attr
     except AttributeError:
@@ -328,7 +330,9 @@ class BugBearVisitor(ast.NodeVisitor):
 
     def check_for_b006(self, node):
         for default in node.args.defaults + node.args.kw_defaults:
-            if isinstance(default, B006.mutable_literals):
+            if isinstance(
+                default, (*B006.mutable_literals, *B006.mutable_comprehensions)
+            ):
                 self.errors.append(B006(default.lineno, default.col_offset))
             elif isinstance(default, ast.Call):
                 call_path = ".".join(self.compose_call_path(default.func))
@@ -653,6 +657,7 @@ B006 = Error(
     )
 )
 B006.mutable_literals = (ast.Dict, ast.List, ast.Set)
+B006.mutable_comprehensions = (ast.ListComp, ast.DictComp, ast.SetComp)
 B006.mutable_calls = {
     "Counter",
     "OrderedDict",
@@ -793,9 +798,10 @@ B903 = Error(
 
 B904 = Error(
     message=(
-        "B904 Within an `except` clause, raise exceptions with `raise ... from err` "
-        "or `raise ... from None` to distinguish them from errors in exception handling.  "
-        "See https://docs.python.org/3/tutorial/errors.html#exception-chaining for details."
+        "B904 Within an `except` clause, raise exceptions with `raise ... from err` or"
+        " `raise ... from None` to distinguish them from errors in exception handling. "
+        " See https://docs.python.org/3/tutorial/errors.html#exception-chaining for"
+        " details."
     )
 )
 
